<?php

App::uses('AppModel', 'Model');

/**
 * Business rules for Pages
 */
class EvPage extends AppModel {

	public $useTable = "pages";

	public $displayField = 'title';

/**
 * Define the number of associated files/documents.
 *
 * @var int|array
 */
	public $documentSlots = -1;

/**
 * @var array Behaviours
 */
	public $actsAs = array(
		'BuzzAdverts.AdvertHost',
		'BuzzTranslate.Translatable',
		'Routable.Routable',
		'MetaData.Meta',
		'Navigation.Navigatable',
		'EvCore.Tabbed'
	);

/**
 * Belongs to associations
 *
 * @var array
 */
	public $belongsTo = array(
		'Theme' => array(
			'className' => 'BuzzTheme.Theme'
		)
	);

/**
 * @var array Validation rules
 */
	public $validate = array(
		'title' => array(
			'required' => array(
				'rule' => 'notEmpty',
				'message' => 'Required'
			),
			'max' => array(
				'rule' => array('maxLength', 150),
				'message' => 'No more than 150 characters'
			)
		),
		'theme_id' => array(
			'required' => array(
				'rule' => 'notEmpty',
				'message' => 'Required'
			)
		),
		'video_url' => array(
			'required' => array(
				'rule' => array('url', true),
				'message' => 'Invalid URL',
				'allowEmpty' => true
			)
		)
	);

/**
 * Constructor
 */
	public function __construct($id = false, $table = null, $ds = null) {
		parent::__construct($id, $table, $ds);

		// If BuzzGallery loaded associate activities with galleries. We're
		// handling this in the constructor so that this feature can easily
		// be disabled on a site if BuzzGallery is excluded.
		if (CakePlugin::loaded('BuzzGallery') === true) {
			$this->belongsTo['Gallery'] = array(
				'className' => 'BuzzGallery.Gallery'
			);
		}

		// Set the multi-experience activity.
		$this->_multiExperience = Configure::read('BuzzBookings.multi_experience');
	}

/**
 * Model pre-save logic
 *
 * @param array $options
 * @return bool
 */
	public function beforeSave($options = array()) {
		// remove trailing empty paragraph tag from body
		if (isset($this->data[$this->alias]['body']) && !empty($this->data[$this->alias]['body'])) {
			$this->data[$this->alias]['body'] = preg_replace("/(<p[^>]*>[\s|&nbsp;]*<\/p>\n?)*$/", '', $this->data[$this->alias]['body']);
		}

		return parent::beforeSave($options);
	}

/**
 * Read for edit.
 *
 * @param int $id
 * @param array $params
 * @return array
 */
	public function readForEdit($id, $params = []) {
		$params['contain']['Advert'] = array(
			'AdvertRelation',
			'AdvertTemplate',
			'Image',
			'order' => array('AdvertRelation.sequence' => 'ASC')
		);
		return parent::readForEdit($id, $params);
	}

/**
 * Read for view.
 *
 * @param int $id
 * @param array $params
 * @return array
 */
	public function readForView($id, $params = []) {
		$data = parent::readForView($id, $params);

		// Get the child menu (if the current page exists in the menu).
		$menuItem = $this->getMenuItem($data);
		$data['Menu'] = $this->_getPageMenu($menuItem);

		return $data;
	}

/**
 * Returns the child menu of a specific menu item.
 *
 * @param array $menuItem
 * @return array
 */
	protected function _getPageMenu($menuItem) {
		$data = [];
		if (!empty($menuItem)) {

			$conditions = array(
				'Menu.rght <' => $menuItem['rght'],
				'Menu.lft >' => $menuItem['lft'],
				'Menu.is_active' => true,
				'Menu.is_menu_hidden' => false
			);

			$order = 'Menu.lft ASC';

			$menu = ClassRegistry::init('Navigatable.Menu')->find('all', compact('conditions', 'order'));
			$data = Hash::extract($menu, '{n}.Menu');

		}
		return $data;
	}

}
